const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const veiculosPage = require('../../../page-objects/parametrizacao/expedicao/veiculos.po.js');
const j = require('../../../json/leitorJson.po');
const protractorHelper = require('protractor-helper');

const max = 999999999;
const min = 99;
const vrMedioLitro = Helper.util.geraInt(min, max);
const quilometragemMdAnual = Helper.util.geraInt(min, max);
const quilometroPorLitro = Helper.util.geraInt(min, max);
const valorIpvaAnual = Helper.util.geraInt(min, max);
const seguroObrigatorioAnual = Helper.util.geraInt(min, max);
const valorLicenciamentoAnual = Helper.util.geraInt(min, max);
const valorManutencaoMensal = Helper.util.geraInt(min, max);
const seguroPrivadoAnual = Helper.util.geraInt(min, max);

fdescribe('Tela Veículos', () => {
	beforeAll(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		veiculosPage.abrir();
		geral.clickFiltro();
	});

	afterAll(() => {
		geral.sair();
	});

	it('Deve acessar a tela Veículos', () => {
		expect(z.component.header.getTitle()).toBe('Veículos');
	});

	it('Deve adicionar um veículo', () => {
		const capacidadeKg = Helper.util.geraInt(min, max);
		const frete = Helper.util.geraInt(min, max);
		const volume = Helper.util.geraInt(min, max);
		const tara = Helper.util.geraInt(min, max);
		geral.clickAdicionar();
		veiculosPage.adicionar(j.getValor('codigo1'), j.getValor('placa'), 'Sim',
			j.getValor('nomeCarro'), j.getValor('municipio'), j.getValor('unidadeFederativa'),
			j.getValor('transportadora'), capacidadeKg, frete, volume, tara, 'Truck',
			'TAC - Agregado', 'Aberta', capacidadeKg, j.getValor('motorista'));
		geral.clickSalvar();
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${veiculosPage.veiculosGridId()}`)));

		expect(geral.gridHasText(veiculosPage.veiculosGridId(), j.getValor('codigo1'), 0, false))
			.toBe(j.getValor('codigo1'));
		expect(geral.gridHasText(veiculosPage.veiculosGridId(), j.getValor('placa'), 1, false))
			.toBe(j.getValor('placa'));
		expect(geral.gridHasText(veiculosPage.veiculosGridId(), j.getValor('nomeCarro'), 2, false))
			.toBe(j.getValor('nomeCarro'));
	});

	it('Deve adicionar Dados para Cálculo do Km Rodado no veículo', () => {
		geral.clickGrid('CDVIATURA', j.getValor('codigo1'), veiculosPage.veiculosGridId());
		geral.clickEditar();
		veiculosPage.adicionaDadosParaCalculo(quilometragemMdAnual, vrMedioLitro, valorIpvaAnual,
			quilometroPorLitro, valorLicenciamentoAnual, seguroObrigatorioAnual, seguroPrivadoAnual,
			valorManutencaoMensal);
		z.component.footer.clickCenterActionByLabel('Calcular Valor do Km Rodado', false);
		geral.clickSalvar();
		geral.waitFieldVisibility('VRKMMEDIAANO');

		expect(geral.getTextoPorId('VRKMMEDIAANO'))
			.toMatch(Helper.util.formataReal(quilometragemMdAnual));
		expect(geral.getTextoPorId('VRMEDLTCOMB'))
			.toMatch(Helper.util.formataReal(vrMedioLitro));
		expect(geral.getTextoPorId('VRIPVAANUAL'))
			.toMatch(Helper.util.formataReal(valorIpvaAnual));
		geral.clickVoltar();
	});

	it('Deve limpar todos campos opcionais no veículo', () => {
		geral.clickGrid('CDVIATURA', j.getValor('codigo1'), veiculosPage.veiculosGridId());
		geral.clickEditar();
		veiculosPage.limparCamposOpcionais('Não', 'VAN', 'TAC - Independente', 'Sider');
		geral.clickSalvar();
		geral.waitFieldVisibility('VRKMMEDIAANO');

		expect(geral.getTextoPorId('NMFANTTRAN'))
			.toBe('');
		expect(geral.getTextoPorId('IDTPPROPRIETA'))
			.toBe('TAC - Independente');
		expect(geral.getTextoPorId('CDVIATURA'))
			.toMatch(j.getValor('codigo1'));
		geral.clickVoltar();
	});

	it('Deve excluir o veículo', () => {
		geral.clickGrid('CDVIATURA', j.getValor('codigo1'), veiculosPage.veiculosGridId());
		veiculosPage.exclui();
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${veiculosPage.veiculosGridId()}`)));

		expect(geral.gridHasText(veiculosPage.veiculosGridId(), j.getValor('codigo1')))
			.toBeUndefined();
		expect(geral.gridHasText(veiculosPage.veiculosGridId(), j.getValor('nomeCarro'), 1))
			.toBeUndefined();
	});
});
